from .views import NotificationListView, NotificationDetailView
from django.conf.urls import url
from django.contrib.auth.decorators import login_required

urlpatterns = [
    url(
        r'^$',
        login_required(NotificationListView.as_view()),
        name='user_notifications'
    ),
    url(
        r'^(?P<pk>\d+)/$',
        login_required(NotificationDetailView.as_view()),
        name='user_notification'
    )
]



from django.db import transaction


__version__ = '1.1.1'


@transaction.atomic()
def notify(
    user, template, summary=None, kind='info', actions=[], tags=[],
    send_email=True, **context
):
    from .models import Notification
    from django.template.loader import render_to_string

    text = render_to_string(
        'notifications/%s.html' % template,
        context
    )

    notification = Notification.objects.create(
        user=user,
        summary=summary or template.replace('_', ' ').capitalize(),
        text=text,
        kind=kind,
        email=send_email
    )

    for ordering, action in enumerate(actions):
        kind, text, url = action
        notification.actions.create(
            kind=kind,
            text=text,
            url=url,
            ordering=ordering
        )

    if isinstance(tags, dict):
        for tag, description in tags.items():
            notification.tags.create(
                slug=tag,
                description=description
            )
    else:
        for tag in sorted(set(tags)):
            notification.tags.create(slug=tag)

    transaction.on_commit(notification.send)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-04-03 16:06
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0002_auto_20171020_0913'),
    ]

    operations = [
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('kind', models.CharField(db_index=True, max_length=20)),
                ('text', models.CharField(max_length=100)),
                ('url', models.URLField(max_length=512)),
                ('ordering', models.PositiveIntegerField(default=0)),
                ('notification', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='actions', to='notifications.Notification')),
            ],
            options={
                'ordering': ('ordering',),
            },
        ),
        migrations.AlterUniqueTogether(
            name='action',
            unique_together=set([('url', 'notification')]),
        ),
    ]



# Generated by Django 2.1.2 on 2019-03-04 11:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0004_auto_20190225_1021'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='email',
            field=models.BooleanField(default=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-05-17 19:53
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Notification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('summary', models.CharField(max_length=255)),
                ('kind', models.CharField(max_length=20)),
                ('sent', models.DateTimeField(auto_now_add=True)),
                ('read', models.BooleanField(default=False)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='notifications', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-sent',),
                'get_latest_by': 'sent',
            },
        ),
    ]



# Generated by Django 2.1.2 on 2019-02-25 16:21

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('notifications', '0003_auto_20180403_1606'),
    ]

    operations = [
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(max_length=100)),
                ('description', models.CharField(max_length=100, null=True)),
                ('notification', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tags', to='notifications.Notification')),
            ],
        ),
        migrations.CreateModel(
            name='UserPreference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tag', models.SlugField(max_length=100)),
                ('email', models.BooleanField()),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='notification_preferences', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='userpreference',
            unique_together={('tag', 'user')},
        ),
        migrations.AlterUniqueTogether(
            name='tag',
            unique_together={('slug', 'notification')},
        ),
    ]
